/*
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.facebook.litho.testing.testrunner;

import com.facebook.litho.config.ComponentsConfiguration;
import org.junit.runners.model.FrameworkMethod;

public class RenderCoreMountStateTestRunConfiguration implements LithoTestRunConfiguration {

  private boolean defaultDelegateToRenderCore;
  private boolean defaultUseExtensions;
  private boolean defaultEnsureParentMounted;

  @Override
  public void beforeTest(FrameworkMethod method) {
    defaultDelegateToRenderCore = ComponentsConfiguration.delegateToRenderCoreMount;
    defaultUseExtensions = ComponentsConfiguration.useExtensionsWithMountDelegate;
    defaultEnsureParentMounted = ComponentsConfiguration.ensureParentMountedInRenderCoreMountState;

    ComponentsConfiguration.delegateToRenderCoreMount = true;
    ComponentsConfiguration.useExtensionsWithMountDelegate = true;
    ComponentsConfiguration.ensureParentMountedInRenderCoreMountState = true;
  }

  @Override
  public void afterTest(FrameworkMethod method) {
    ComponentsConfiguration.delegateToRenderCoreMount = defaultDelegateToRenderCore;
    ComponentsConfiguration.useExtensionsWithMountDelegate = defaultUseExtensions;
    ComponentsConfiguration.ensureParentMountedInRenderCoreMountState = defaultEnsureParentMounted;
  }
}
