/*
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.facebook.samples.litho.java.changesetdebug;

import com.facebook.litho.Column;
import com.facebook.litho.Component;
import com.facebook.litho.ComponentContext;
import com.facebook.litho.annotations.LayoutSpec;
import com.facebook.litho.annotations.OnCreateLayout;
import com.facebook.litho.annotations.Prop;
import com.facebook.litho.sections.SectionContext;
import com.facebook.litho.sections.widget.RecyclerCollectionComponent;
import com.facebook.litho.widget.Text;
import java.util.List;

@LayoutSpec
public class StateResettingRootComponentSpec {

  @OnCreateLayout
  static Component onCreateLayout(
      ComponentContext c, @Prop List<DataModel> dataModels, @Prop boolean showHeader) {

    final Component listComponent =
        RecyclerCollectionComponent.create(c)
            .disablePTR(true)
            .section(FavouriteGroupSection.create(new SectionContext(c)).dataModels(dataModels))
            .flexGrow(1)
            .build();

    return showHeader
        ? Column.create(c)
            .child(Text.create(c).text("Header").textSizeDip(30).build())
            .child(listComponent)
            .build()
        : listComponent;
  }
}
